We'd love you to contribute to Otterdog!
Check out the sub-documents for more information on how to contribute.

## Eclipse Contributor Agreement (ECA)

Log into the [Eclipse projects forge](https://www.eclipse.org/contribute/cla) (you will need to create
an account with the Eclipse Foundation if you have not already done so); click on "Eclipse Contributor
Agreement"; and Complete the form. Be sure to use the same email address when you register for the
account that you intend to use on Git commit records.

[More about ECA FAQ](https://www.eclipse.org/legal/eca/)


## Issues

Questions, feature requests and bug reports are all welcome as
[discussions](https://github.com/eclipse-csi/otterdog/discussions) or
[issues](https://github.com/eclipse-csi/otterdog/issues).
